@@ -35,6 +35,7 @@ from lib.gui.pluginwin import PluginManagerWindow
 from lib.gui.dicteditorwin import DictEditorWindow
 from lib.gui.dictaddwin import DictAddWindow
 from lib.gui.prefswin import PrefsWindow
+from lib.gui import prefswin
 from lib.gui.helpwin import LicenseWindow, AboutWindow
 from lib.gui import errorwin
 from lib.gui import miscwin
@@ -94,15 +95,16 @@ class HtmlWindow(wxHtmlWindow):
          systemLog(ERROR, "Unable to decode '%s': %s" % (word.encode('UTF-8'),
                                                          e))
          title = _("Encode Failed")
-         msg = _("Unable to encode text \"%s\" in %s for \"%s\"." \
+         msg = _("Unable to encode text \"%s\" in %s for \"%s\".") \
                  % (enc.toWX(word), parent.activeDictionary.getEncoding(),
-                 parent.activeDictionary.getName()))
+                 parent.activeDictionary.getName())
                     
          errorwin.showErrorMessage(title, msg)
 
          return
       
       parent.SetStatusText(_("Searching..."))
+      parent.entry.SetValue(word)
       parent.timerSearch.Start(parent.delay)
       parent.search = Process(parent.activeDictionary.search,
                               word)
@@ -262,12 +264,17 @@ class MainWindow(wxFrame):
       #
       self.menuDict = wxMenu()
 
-      dictNames = []
+      dicts = []
       for dictionary in self.app.dictionaries.values():
-         dictNames.append(dictionary.getName())
-      dictNames.sort()
+         dicts.append([dictionary.getName(), dictionary.getActive()])
+      dicts.sort()
       
-      for name in dictNames:
+      for name, active in dicts:
+         #if not self.app.config.activedict.enabled(name):
+         #    continue
+         if not active:
+             continue
+
          encoded = enc.toWX(name)
 
          itemID = self.app.config.ids.keys()[\
@@ -300,6 +307,9 @@ class MainWindow(wxFrame):
       menuTools.Append(idManageDict, _("Manage Dictionaries...\tCtrl-M"),
                       _("Install or remove dictionaries"))
 
+      menuTools.Append(5002, _("Create Dictionaries..."),
+                       _("Create and edit dictionaries"))  
+                           
       menuTools.AppendSeparator()
 
       idUseScan = wx.NewId()
@@ -318,10 +328,12 @@ class MainWindow(wxFrame):
                           _("Open connection to DICT server"))
 
       menuTools.AppendSeparator()
-      
-      menuTools.Append(5002, _("Create Dictionaries..."),
-                       _("Create and edit dictionaries"))  
+
+      idPron = wx.NewId()
+      menuTools.Append(idPron, _("Pronounce\tCtrl-E"),
+          _("Pronounce word"))  
                            
+      
       self.menuBar.Append(menuTools, _("Tools"))
 
 
@@ -330,11 +342,6 @@ class MainWindow(wxFrame):
       #
       menuHelp = wxMenu()
 
-      idLicence = wx.NewId()
-      menuHelp.Append(idLicence, _("&License"))
-      
-      menuHelp.AppendSeparator()
-      
       idAbout = wx.NewId()
       menuHelp.Append(idAbout, _("&About\tCtrl-A"))
 
@@ -343,7 +350,7 @@ class MainWindow(wxFrame):
       self.SetMenuBar(self.menuBar)
 
       # Search Bar
-      labelWord = wxStaticText(self, -1, _("Word:"));
+      labelWord = wxStaticText(self, -1, _("Word:"))
       self.hboxToolbar.Add(labelWord, 0, wxALL | wxCENTER | wx.ALIGN_RIGHT, 5)
       
       self.entry = wxComboBox(self, 153, "", wxPoint(-1, -1),
@@ -494,9 +501,9 @@ class MainWindow(wxFrame):
       EVT_MENU(self, idManageDict, self.onShowPluginManager)
       EVT_MENU(self, 5002, self.onShowDictEditor)
       EVT_MENU(self, idPrefs, self.onShowPrefsWindow)
+      EVT_MENU(self, idPron, self.onPronounce)
 
       # Help menu events
-      EVT_MENU(self, idLicence, self.onLicence)
       EVT_MENU(self, idAbout, self.onAbout)
 
       # Other events
@@ -514,7 +521,7 @@ class MainWindow(wxFrame):
       EVT_TIMER(self, idClipboard, self.onTimerClipboard)
       EVT_CLOSE(self, self.onCloseWindow)
 
-      EVT_KEY_DOWN(self, self.onKeyDown)
+      self.entry.Bind(wx.EVT_KEY_DOWN, self.onKeyDown)
 
       # Prepare help message
       self.htmlCode = _("""
@@ -593,7 +600,7 @@ class MainWindow(wxFrame):
          try:
             assert result.__class__ == meta.SearchResult
          except:
-            self.SetStatusText(_(errortype.INTERNAL_ERROR.getMessage()))
+            self.SetStatusText(errortype.INTERNAL_ERROR.getMessage())
 
             if self.activeDictionary.getType() == dicttype.PLUGIN:
                title = errortype.INTERNAL_ERROR.getMessage()
@@ -638,11 +645,11 @@ class MainWindow(wxFrame):
             systemLog(ERROR, "Unable to decode translation in %s (%s)" \
                       % (self.activeDictionary.getEncoding(),
                          e))
-            title = _(errortype.INVALID_ENCODING.getMessage())
+            title = errortype.INVALID_ENCODING.getMessage()
             msg = _("Translation cannot be displayed using selected " \
                     "encoding %s. Please try another encoding from " \
-                    "View > Character Encoding menu." \
-                    % self.activeDictionary.getEncoding())
+                    "View > Character Encoding menu.") \
+                    % self.activeDictionary.getEncoding()
             self.SetStatusText(title)
             errorwin.showErrorMessage(title, msg)
             return 
@@ -698,19 +705,14 @@ class MainWindow(wxFrame):
          wxTheClipboard.Close()
          return enc.toWX(text)
       
-
-      def clear():
-         do = wxTextDataObject()
-         do.SetText('')
-         wxTheClipboard.Open()
-         wxTheClipboard.SetData(do)
-         wxTheClipboard.Close()
-
       text = getText()
-      if text:
+      old_text = ''
+      if hasattr(self, 'old_clipboard_text'):
+          old_text = self.old_clipboard_text
+      if text and text != old_text:
          self.entry.SetValue(text)
          self.onSearch(None)
-         clear()
+         self.old_clipboard_text = text
 
 
    def onUseScanClipboard(self, event):
@@ -775,11 +777,11 @@ class MainWindow(wxFrame):
          systemLog(ERROR, "Unable to decode '%s': %s" % (word.encode('UTF-8'),
                                                          e))
          title = _("Encode Failed")
-         msg = _("Unable to encode text \"%s\" in %s for \"%s\". " \
-                 "That logically means the word " \
-                 "definition does not exist in the dictionary." \
+         msg = _("Unable to encode text \"%s\" in %s for \"%s\". "
+                 "That logically means the word "
+                 "definition does not exist in the dictionary.") \
                  % (enc.toWX(word), self.activeDictionary.getEncoding(),
-                 self.activeDictionary.getName()))
+                 self.activeDictionary.getName())
                     
          errorwin.showErrorMessage(title, msg)
 
@@ -825,14 +827,16 @@ class MainWindow(wxFrame):
 
    def onClean(self, event):
       self.entry.SetValue("")
+      self.entry.SetFocus()
          
 
    def onKeyDown(self, event):
       """Key down event handler."""
+
       key = event.KeyCode()
       if key == wx.WXK_ESCAPE:
-         self.entry.SetValue("")
-      return
+         self.onClean(None)
+      event.Skip()
 
 
    def onClearHistory(self, event):
@@ -917,6 +921,32 @@ class MainWindow(wxFrame):
       wxTheClipboard.Close()
 
 
+   def onPronounce(self, event):
+      """Pronouce word using external software."""
+
+      word = self.entry.GetValue().strip()
+      if word:
+        cmd = self.app.config.get('pronunciationCommand') or prefswin.PRON_COMMAND
+
+        if self.app.config.get('pronounceTrans') == 'True':
+            word = html2text(self.htmlCode)
+        
+        import locale
+        localeCharset = locale.getpreferredencoding()
+
+        try:
+            word = word.replace('(', '').replace(')', '').replace('\n', 
+                '').replace('\r', '').replace('"', '\\"')
+            cmd = (cmd % word).encode(localeCharset)
+            Process(os.system, cmd)
+        except Exception, e:
+            traceback.print_exc()
+            title = _("Error")
+            msg = _("Unable to decode text using your locale charset %s" \
+                % localeCharset)
+            errorwin.showErrorMessage(title, msg)
+            
+
    def onShowGroupsWindow(self, event):
       """This method is invoked when Groups menu item is selected"""
       self.groupsWindow = GroupsWindow(self, -1,
@@ -1023,7 +1053,16 @@ class MainWindow(wxFrame):
                         dictInstance.getName())
       EVT_MENU(self, unid, self.onDefault)
       
-      self.menuDict.InsertItem(self.menuDict.GetMenuItemCount()-2, item)
+      #self.menuDict.InsertItem(self.menuDict.GetMenuItemCount()-2, item)
+      self.menuDict.InsertItem(0, item)
+
+
+   def removeDictionary(self, name):
+       """Remove dictionary from the menu"""
+
+       item = self.menuDict.FindItem(name)
+       if item:
+           self.menuDict.Delete(item)
 
 
    def loadDictionary(self, dictInstance):
@@ -1081,7 +1120,7 @@ class MainWindow(wxFrame):
                        "character encoding %s is not correct for this " \
                        "dictionary. Try selecting " \
                        "another encoding from View > Character Encoding " \
-                       "menu" % self.app.config.get('encoding'))
+                       "menu") % self.app.config.get('encoding')
 
                from lib.gui import errorwin
                errorwin.showErrorMessage(title, msg)
@@ -1097,8 +1136,8 @@ class MainWindow(wxFrame):
             wx.EndBusyCursor()
             traceback.print_exc()
             title = _("Error")
-            msg = _("Unable to load dictionary index table. " \
-                    "Got error: %s" % e)
+            msg = _("Unable to load dictionary index table. "
+                    "Got error: %s") % e
             from lib.gui import errorwin
             errorwin.showErrorMessage(title, msg)
             return
@@ -1170,6 +1209,8 @@ class MainWindow(wxFrame):
       self.app.config.set('encoding', misc.encodings[name])
 
       if self.activeDictionary:
+         print "Setting encoding %s for dictionary %s" % \
+            (self.app.config.get('encoding'), self.activeDictionary.name)
          self.activeDictionary.setEncoding(self.app.config.get('encoding'))
          systemLog(INFO, "Dictionary encoding set to %s" \
                % self.activeDictionary.getEncoding())
@@ -1296,17 +1337,6 @@ class MainWindow(wxFrame):
       systemLog(WARNING, "Manual function is not impelemented yet")
       
 
-   def onLicence(self, event):
-      """Shows 'License' window"""
-
-      licenseWindow = LicenseWindow(self, -1,
-                                _("License"),
-                                size=(500, 400),
-                                style=wxDEFAULT_FRAME_STYLE)
-      licenseWindow.CenterOnScreen()
-      licenseWindow.Show(True)
-
-
    def onAbout(self, event):
       """Shows 'About' window"""
 
